@@ -11,6 +11,7 @@ class ActivityItem : public QObject
 {
     Q_OBJECT
 
+#if QT_VERSION >= 0x040700
     Q_PROPERTY(QString id
                READ id
                CONSTANT)
@@ -41,6 +42,7 @@ class ActivityItem : public QObject
     Q_PROPERTY(QUrl thumbnailUrl
                READ thumbnailUrl
                NOTIFY thumbnailUrlChanged)
+#endif
 
 public:
     explicit ActivityItem(QObject *parent = 0);
