@@ -9,6 +9,9 @@
 #endif
 #include <QNetworkReply>
 #include <QTimer>
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 
 using namespace QtJson;
 
@@ -25,23 +28,24 @@ ActivityListModel::ActivityListModel(QObject * parent) :
     m_refresh(false)
 {
 #if QT_VERSION >= 0x040600
-    QHash<int, QByteArray> roles;
-    roles[IdRole] = "id";
-    roles[TitleRole] = "title";
-    roles[ArtistRole] = "artist";
-    roles[ArtistIdRole] = "artistId";
-    roles[ArtistAvatarUrlRole] = "artistAvatarUrl";
-    roles[ThumbnailUrlRole] = "thumbnailUrl";
+    m_roleNames[IdRole] = "id";
+    m_roleNames[TitleRole] = "title";
+    m_roleNames[ArtistRole] = "artist";
+    m_roleNames[ArtistIdRole] = "artistId";
+    m_roleNames[ArtistAvatarUrlRole] = "artistAvatarUrl";
+    m_roleNames[ThumbnailUrlRole] = "thumbnailUrl";
 #ifndef QML_USER_INTERFACE
-    roles[ArtistAvatarRole] = "artistAvatar";
-    roles[ThumbnailRole] = "thumbnail";
-    roles[ArtistAvatarPressedRole] = "artistAvatarPressed";
-    roles[ThumbnailPressedRole] = "thumbnailPressed";
+    m_roleNames[ArtistAvatarRole] = "artistAvatar";
+    m_roleNames[ThumbnailRole] = "thumbnail";
+    m_roleNames[ArtistAvatarPressedRole] = "artistAvatarPressed";
+    m_roleNames[ThumbnailPressedRole] = "thumbnailPressed";
+#endif
+    m_roleNames[BodyRole] = "body";
+    m_roleNames[DateRole] = "date";
+    m_roleNames[ActivityTypeRole] = "activityType";
+#if QT_VERSION < 0x050000
+    this->setRoleNames(m_roleNames);
 #endif
-    roles[BodyRole] = "body";
-    roles[DateRole] = "date";
-    roles[ActivityTypeRole] = "activityType";
-    this->setRoleNames(roles);
 #endif
 #ifndef QML_USER_INTERFACE
     this->connect(m_cache, SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
@@ -56,6 +60,12 @@ ActivityListModel::~ActivityListModel() {
 #endif
 }
 
+#if QT_VERSION >= 0x050000
+QHash<int, QByteArray> ActivityListModel::roleNames() const {
+    return m_roleNames;
+}
+#endif
+
 void ActivityListModel::clear() {
     this->beginRemoveRows(QModelIndex(), 0, this->rowCount() - 1);
     m_list.clear();
@@ -224,7 +234,13 @@ void ActivityListModel::getActivities(QUrl feed) {
     }
 
     if (!this->cursor().isEmpty()) {
+#if QT_VERSION >= 0x050000
+        QUrlQuery query(feed);
+        query.addQueryItem("cursor", this->cursor());
+        feed.setQuery(query);
+#else
         feed.addQueryItem("cursor", this->cursor());
+#endif
     }
 
     this->setLoading(true);
@@ -265,11 +281,17 @@ void ActivityListModel::addActivities() {
             }
 
             QUrl next = res.value("next_href").toString();
+#if QT_VERSION >= 0x050000
+            QUrlQuery query(next);
 
+            if (query.hasQueryItem("cursor")) {
+                this->setCursor(query.queryItemValue("cursor"));
+            }
+#else
             if (next.hasQueryItem("cursor")) {
                 this->setCursor(next.queryItemValue("cursor"));
             }
-
+#endif
             this->setMoreResults(!entries.isEmpty());
             QTimer::singleShot(1000, this, SLOT(stopLoading()));
         }
