@@ -51,6 +51,9 @@ public:
 public:
     explicit ActivityListModel(QObject *parent = 0);
     ~ActivityListModel();
+#if QT_VERSION >= 0x050000
+    QHash<int, QByteArray> roleNames() const;
+#endif
     inline QUrl feed() const { return m_feed; }
     void setFeed(const QUrl &feed);
     inline bool loading() const { return m_loading; }
@@ -115,6 +118,9 @@ private:
     bool m_error;
     bool m_refresh;
     QList< QSharedPointer<ActivityItem> >  m_list;
+#if QT_VERSION >= 0x040600
+    QHash<int, QByteArray> m_roleNames;
+#endif
 };
 
 #endif // ACTIVITYLISTMODEL_H
