@@ -37,7 +37,7 @@ signals:
 #endif
 
 private:
-    static ClipboardMonitor* m_instance;
+    static ClipboardMonitor* self;
     QString m_clipboardUrl;
 #ifdef MEEGO_EDITION_HARMATTAN
     QTimer *m_timer;
