@@ -5,7 +5,7 @@ CommentItem::CommentItem(QObject *parent) :
     QObject(parent),
     m_timestamp(0),
     m_indent(0),
-    m_loading(false),
+    m_loading(true),
     m_service(Services::NoService)
 {
 }
@@ -37,7 +37,7 @@ CommentItem::CommentItem(const QVariantMap &comment, QObject *parent) :
     m_timestamp(comment.value("timestamp").toLongLong()),
     m_trackId(comment.value("track_id").toString()),
     m_indent(0),
-    m_loading(false),
+    m_loading(true),
     m_service(Services::SoundCloud)
 {
 }
