@@ -11,6 +11,7 @@ class CommentItem : public QObject
 {
     Q_OBJECT
 
+#if QT_VERSION >= 0x040700
     Q_PROPERTY(QString id
                READ id
                CONSTANT)
@@ -38,6 +39,7 @@ class CommentItem : public QObject
     Q_PROPERTY(Services::AudioService service
                READ service
                NOTIFY serviceChanged)
+#endif
 
 public:
     explicit CommentItem(QObject *parent = 0);
