@@ -46,6 +46,9 @@ public:
 public:
     explicit CommentListModel(QObject *parent = 0);
     ~CommentListModel();
+#if QT_VERSION >= 0x050000
+    QHash<int, QByteArray> roleNames() const;
+#endif
     inline QString trackId() const { return m_trackId; }
     void setTrackId(const QString &id = QString());
     inline QUrl feed() const { return m_feed; }
@@ -108,6 +111,9 @@ private:
     bool m_error;
     int m_offset;
     QList< QSharedPointer<CommentItem> > m_list;
+#if QT_VERSION >= 0x040600
+    QHash<int, QByteArray> m_roleNames;
+#endif
 };
 
 #endif // COMMENTLISTMODEL_H
