@@ -11,9 +11,13 @@
 #include <QUrl>
 #include <QDebug>
 #include <QThread>
+#if QT_VERSION >= 0x050000
+#include <QStandardPaths>
+#else
 #include <QDesktopServices>
+#endif
 
-Database* Database::m_instance = 0;
+Database* Database::self = 0;
 
 Database::Database() :
     QObject(),
@@ -22,8 +26,8 @@ Database::Database() :
     m_busy(false),
     m_cancelled(false)
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 
     this->moveToThread(m_thread);
@@ -34,6 +38,10 @@ Database::Database() :
     m_database.setDatabaseName("/home/user/MusiKloud/MusiKloud.sqlite");
 #elif (defined (SYMBIAN_OS))
     m_database.setDatabaseName("MusiKloud.sqlite");
+#elif QT_VERSION >= 0x050000
+    QDir dir(QStandardPaths::writableLocation(QStandardPaths::HomeLocation) + "/MusiKloud/");
+    dir.mkpath(dir.path());
+    m_database.setDatabaseName(dir.path() + "/MusiKloud.sqlite");
 #else
     QDir dir(QDesktopServices::storageLocation(QDesktopServices::HomeLocation) + "/MusiKloud/");
     dir.mkpath(dir.path());
@@ -50,7 +58,7 @@ Database::~Database() {
 }
 
 Database* Database::instance() {
-    return !m_instance ? new Database : m_instance;
+    return !self ? new Database : self;
 }
 
 void Database::initialize() {
