@@ -7,6 +7,8 @@
 #include <qplatformdefs.h>
 #ifdef MEEGO_EDITION_HARMATTAN
 #include "../harmattan/transferitem.h"
+#elif (defined (Q_WS_SAILFISH))
+#include "../sailfish/transferitem.h"
 #elif (defined (Q_WS_MAEMO_5))
 #include "../maemo5/transferitem.h"
 #elif (defined (Q_WS_MAEMO_4))
@@ -85,7 +87,7 @@ signals:
     void currentOperationCancelled();
 
 private:
-    static Database* m_instance;
+    static Database* self;
     QThread *m_thread;
     QSqlDatabase m_database;
     bool m_busy;
