@@ -32,6 +32,9 @@ public:
 
 public:
     explicit ExploreModel(QObject *parent = 0);
+#if QT_VERSION >= 0x050000
+    QHash<int, QByteArray> roleNames() const;
+#endif
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
     QVariant data(const QModelIndex &index, int role) const;
 #if QT_VERSION >= 0x040600
@@ -46,6 +49,9 @@ signals:
     
 private:
     QList<ExploreItem> m_list;
+#if QT_VERSION >= 0x040600
+    QHash<int, QByteArray> m_roleNames;
+#endif
 };
 
 #endif // EXPLOREMODEL_H
