@@ -3,13 +3,13 @@
 
 #include <QUrl>
 
-const QUrl TRACKS_BASE_FEED("http://api.soundcloud.com/tracks.json?limit=30&filter=public,streamable");
+const QUrl TRACKS_BASE_FEED("http://api.soundcloud.com/tracks.json?limit=30&filter=public");
 const QUrl PLAYLISTS_BASE_FEED("http://api.soundcloud.com/playlists.json?limit=30");
 const QUrl USERS_BASE_FEED("http://api.soundcloud.com/users.json?limit=30");
 const QUrl GROUPS_BASE_FEED("http://api.soundcloud.com/groups.json?limit=30");
 
-const QUrl UPLOADS_FEED("https://api.soundcloud.com/me/tracks.json?limit=30&filter=public,streamable");
-const QUrl FAVOURITES_FEED("https://api.soundcloud.com/me/favorites.json?limit=30&filter=public,streamable");
+const QUrl UPLOADS_FEED("https://api.soundcloud.com/me/tracks.json?limit=30&filter=public");
+const QUrl FAVOURITES_FEED("https://api.soundcloud.com/me/favorites.json?limit=30&filter=public");
 const QUrl PLAYLISTS_FEED("https://api.soundcloud.com/me/playlists.json?limit=30");
 const QUrl GROUPS_FEED("https://api.soundcloud.com/me/groups.json?limit=30");
 const QUrl FOLLOWERS_FEED("https://api.soundcloud.com/me/followers.json?limit=30");
