@@ -31,10 +31,10 @@ GroupItem::GroupItem(const QVariantMap &group, QObject *parent) :
     m_title(group.value("name").toString()),
     m_artist(group.value("creator").toMap().value("username").toString()),
     m_artistId(group.value("creator").toMap().value("id").toString()),
-    m_artistAvatarUrl(group.value("creator").toMap().value("avatar_url").toUrl()),
+    m_artistAvatarUrl(group.value("creator").toMap().value("avatar_url").toString()),
     m_description(group.value("description").toString().remove('\r')),
     m_date(Utils::localDateTimeFromString(group.value("created_at").toString().section(' ', 0, 1))),
-    m_thumbnailUrl(group.value("artwork_url").toUrl()),
+    m_thumbnailUrl(group.value("artwork_url").toString()),
     m_trackCount(group.value("track_count").toInt()),
     m_member(false),
     m_service(Services::SoundCloud)
