@@ -11,6 +11,7 @@ class GroupItem : public QObject
 {
     Q_OBJECT
 
+#if QT_VERSION >= 0x040700
     Q_PROPERTY(QString id
                READ id
                CONSTANT)
@@ -45,6 +46,7 @@ class GroupItem : public QObject
     Q_PROPERTY(Services::AudioService service
                READ service
                NOTIFY serviceChanged)
+#endif
 
 public:
     explicit GroupItem(QObject *parent = 0);
