@@ -24,17 +24,18 @@ GroupListModel::GroupListModel(QObject *parent) :
     m_offset(0)
 {
 #if QT_VERSION >= 0x040600
-    QHash<int, QByteArray> roles;
-    roles[IdRole] = "id";
-    roles[TitleRole] = "title";
-    roles[ArtistRole] = "artist";
-    roles[DateRole] = "date";
+    m_roleNames[IdRole] = "id";
+    m_roleNames[TitleRole] = "title";
+    m_roleNames[ArtistRole] = "artist";
+    m_roleNames[DateRole] = "date";
 #ifndef QML_USER_INTERFACE
-    roles[ThumbnailRole] = "thumbnail";
+    m_roleNames[ThumbnailRole] = "thumbnail";
+#endif
+    m_roleNames[ThumbnailUrlRole] = "thumbnailUrl";
+    m_roleNames[DescriptionRole] = "description";
+#if QT_VERSION < 0x050000
+    this->setRoleNames(m_roleNames);
 #endif
-    roles[ThumbnailUrlRole] = "thumbnailUrl";
-    roles[DescriptionRole] = "description";
-    this->setRoleNames(roles);
 #endif
 #ifndef QML_USER_INTERFACE
     this->connect(m_cache, SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
@@ -49,12 +50,18 @@ GroupListModel::~GroupListModel() {
 #endif
 }
 
+#if QT_VERSION >= 0x050000
+QHash<int, QByteArray> GroupListModel::roleNames() const {
+    return m_roleNames;
+}
+#endif
+
 void GroupListModel::clear() {
     this->beginRemoveRows(QModelIndex(), 0, this->rowCount() - 1);
     m_list.clear();
     this->endRemoveRows();
     this->setLoading(false);
-    this->setOffset(1);
+    this->setOffset(0);
     this->setMoreResults(true);
     this->setError(false);
 }
