@@ -41,6 +41,9 @@ public:
 public:
     explicit GroupListModel(QObject *parent = 0);
     ~GroupListModel();
+#if QT_VERSION >= 0x050000
+    QHash<int, QByteArray> roleNames() const;
+#endif
     inline QUrl feed() const { return m_feed; }
     void setFeed(const QUrl &feed);
     inline bool loading() const { return m_loading; }
@@ -102,6 +105,9 @@ private:
     bool m_error;
     int m_offset;
     QList< QSharedPointer<GroupItem> > m_list;
+#if QT_VERSION >= 0x040600
+    QHash<int, QByteArray> m_roleNames;
+#endif
 };
 
 #endif // DAILYMOTIONGROUPLISTMODEL_H
