@@ -17,6 +17,10 @@ public:
 
 public:
     explicit HomescreenModel(QObject *parent = 0);
+    ~HomescreenModel();
+#if QT_VERSION >= 0x050000
+    QHash<int, QByteArray> roleNames() const;
+#endif
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
     QVariant data(const QModelIndex &index, int role) const;
 #if QT_VERSION >= 0x040600
@@ -25,6 +29,9 @@ public:
     
 private:
     QList< QPair<QString, QString> > m_list;
+#if QT_VERSION >= 0x040600
+    QHash<int, QByteArray> m_roleNames;
+#endif
 };
 
 #endif // HOMESCREENMODEL_H
