@@ -12,21 +12,21 @@
 const QString API_KEY("ac4c4586cc1441c74011bf89b28af6b3");
 const QString API_SECRET("05e69588c52c6da942f56d3faed3c45f");
 
-Lastfm* Lastfm::m_instance = 0;
+Lastfm* Lastfm::self = 0;
 
 Lastfm::Lastfm(QObject *parent) :
     QObject(parent),
     m_nam(0)
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 }
 
 Lastfm::~Lastfm() {}
 
 Lastfm* Lastfm::instance() {
-    return !m_instance ? new Lastfm : m_instance;
+    return !self ? new Lastfm : self;
 }
 
 void Lastfm::setBusy(bool isBusy, const QString &message, int numberOfOperations) {
@@ -86,7 +86,7 @@ QByteArray Lastfm::getPostData(const QMap<QString, QString> &params) {
         }
     }
 
-    return postData.toAscii();
+    return postData.toUtf8();
 }
 
 QString Lastfm::getAuthToken(const QString &user, const QString &pass) {
