@@ -13,7 +13,7 @@
 #endif
 #endif
 
-Notifications* Notifications::m_instance = 0;
+Notifications* Notifications::self = 0;
 
 Notifications::Notifications(QObject *parent) :
     QObject(parent)
@@ -21,13 +21,13 @@ Notifications::Notifications(QObject *parent) :
     ,m_progressDialog(0)
   #endif
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 }
 
 Notifications* Notifications::instance() {
-    return !m_instance ? new Notifications : m_instance;
+    return !self ? new Notifications : self;
 }
 
 #ifdef Q_WS_MAEMO_5
@@ -126,6 +126,12 @@ void Notifications::showProgressDialog(const QString &message, int numberOfOpera
     if (this->sender()) {
         this->connect(m_progressDialog, SIGNAL(canceled()), this->sender(), SLOT(cancelCurrentOperation()));
     }
+#elif defined (QML_USER_INTERFACE)
+    if (this->sender()) {
+        this->connect(this, SIGNAL(canceled()), this->sender(), SLOT(cancelCurrentOperation()));
+    }
+
+    emit busy(message, numberOfOperations);
 #else
     emit busy(message, numberOfOperations);
 #endif
@@ -141,8 +147,9 @@ void Notifications::updateProgressDialog(int progress) {
 #endif
 }
 
-#if (!defined (QML_USER_INTERFACE)) && (defined (Q_WS_MAEMO_5))
+#ifndef Q_WS_MAEMO_4
 void Notifications::cancelProgressDialog() {
+#ifndef QML_USER_INTERFACE
     if (m_progressDialog) {
         m_progressDialog->reset();
 
@@ -150,5 +157,13 @@ void Notifications::cancelProgressDialog() {
             this->disconnect(m_progressDialog, SIGNAL(canceled()), this->sender(), SLOT(cancelCurrentOperation()));
         }
     }
-}
+#else
+    if (this->sender()) {
+        this->disconnect(this, SIGNAL(canceled()), this->sender(), SLOT(cancelCurrentOperation()));
+    }
+    else {
+        emit canceled();
+    }
 #endif
+}
+#endif
\ No newline at end of file
