@@ -29,7 +29,7 @@ public slots:
     void onError(const QString &message);
     void showProgressDialog(const QString &message, int numberOfOperations);
     void updateProgressDialog(int progress);
-#if (!defined (QML_USER_INTERFACE)) && (defined (Q_WS_MAEMO_5))
+#ifndef Q_WS_MAEMO_4
     void cancelProgressDialog();
 #endif
 
@@ -39,9 +39,12 @@ signals:
     void error(const QString &message);
     void busy(const QString &message, int numberOfOperations);
     void busyProgressChanged(int progress);
+#ifdef QML_USER_INTERFACE
+    void canceled();
+#endif
 
 private:
-    static Notifications* m_instance;
+    static Notifications* self;
 #if (!defined (QML_USER_INTERFACE)) && (defined (Q_WS_MAEMO_5))
     QProgressDialog *m_progressDialog;
 #endif
