@@ -18,24 +18,25 @@ PlaybackListModel::PlaybackListModel(QObject *parent) :
     }
 
 #if QT_VERSION >= 0x040600
-    QHash<int, QByteArray> roles;
-    roles[IdRole] = "id";
-    roles[PlaylistIdRole] = "playlistId";
-    roles[TitleRole] = "title";
-    roles[ArtistRole] = "artist";
-    roles[DateRole] = "date";
-    roles[DurationRole] = "duration";
-    roles[UrlRole] = "url";
-    roles[StreamUrlRole] = "streamUrl";
+    m_roleNames[IdRole] = "id";
+    m_roleNames[PlaylistIdRole] = "playlistId";
+    m_roleNames[TitleRole] = "title";
+    m_roleNames[ArtistRole] = "artist";
+    m_roleNames[DateRole] = "date";
+    m_roleNames[DurationRole] = "duration";
+    m_roleNames[UrlRole] = "url";
+    m_roleNames[StreamUrlRole] = "streamUrl";
 #ifndef QML_USER_INTERFACE
-    roles[ThumbnailRole] = "thumbnail";
-    roles[ThumbnailPressedRole] = "thumbnailPressed";
+    m_roleNames[ThumbnailRole] = "thumbnail";
+    m_roleNames[ThumbnailPressedRole] = "thumbnailPressed";
+#endif
+    m_roleNames[ThumbnailUrlRole] = "thumbnailUrl";
+    m_roleNames[ServiceRole] = "service";
+    m_roleNames[FavouriteRole] = "favourite";
+    m_roleNames[SelectedRole] = "selected";
+#if QT_VERSION < 0x050000
+    this->setRoleNames(m_roleNames);
 #endif
-    roles[ThumbnailUrlRole] = "thumbnailUrl";
-    roles[ServiceRole] = "service";
-    roles[FavouriteRole] = "favourite";
-    roles[SelectedRole] = "selected";
-    this->setRoleNames(roles);
 #endif
 #ifndef QML_USER_INTERFACE
     this->connect(m_cache, SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
@@ -50,6 +51,12 @@ PlaybackListModel::~PlaybackListModel() {
 #endif
 }
 
+#if QT_VERSION >= 0x050000
+QHash<int, QByteArray> PlaybackListModel::roleNames() const {
+    return m_roleNames;
+}
+#endif
+
 PlaybackListModel* PlaybackListModel::playbackQueue() {
     return !m_queue ? new PlaybackListModel : m_queue;
 }
