@@ -11,6 +11,7 @@ class PlaylistItem : public QObject
 {
     Q_OBJECT
 
+#if QT_VERSION >= 0x040700
     Q_PROPERTY(QString id
                READ id
                CONSTANT)
@@ -47,6 +48,7 @@ class PlaylistItem : public QObject
     Q_PROPERTY(Services::AudioService service
                READ service
                NOTIFY serviceChanged)
+#endif
 
 public:
     explicit PlaylistItem(QObject *parent = 0);
