@@ -24,18 +24,19 @@ PlaylistListModel::PlaylistListModel(QObject *parent) :
     m_offset(0)
 {
 #if QT_VERSION >= 0x040600
-    QHash<int, QByteArray> roles;
-    roles[IdRole] = "id";
-    roles[TitleRole] = "title";
-    roles[ArtistRole] = "artist";
-    roles[DateRole] = "date";
-    roles[TrackCountRole] = "trackCount";
+    m_roleNames[IdRole] = "id";
+    m_roleNames[TitleRole] = "title";
+    m_roleNames[ArtistRole] = "artist";
+    m_roleNames[DateRole] = "date";
+    m_roleNames[TrackCountRole] = "trackCount";
 #ifndef QML_USER_INTERFACE
-    roles[ThumbnailRole] = "thumbnail";
+    m_roleNames[ThumbnailRole] = "thumbnail";
+#endif
+    m_roleNames[ThumbnailUrlRole] = "thumbnailUrl";
+    m_roleNames[DescriptionRole] = "description";
+#if QT_VERSION < 0x050000
+    this->setRoleNames(m_roleNames);
 #endif
-    roles[ThumbnailUrlRole] = "thumbnailUrl";
-    roles[DescriptionRole] = "description";
-    this->setRoleNames(roles);
 #endif
 #ifndef QML_USER_INTERFACE
     this->connect(m_cache, SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
@@ -50,12 +51,18 @@ PlaylistListModel::~PlaylistListModel() {
 #endif
 }
 
+#if QT_VERSION >= 0x050000
+QHash<int, QByteArray> PlaylistListModel::roleNames() const {
+    return m_roleNames;
+}
+#endif
+
 void PlaylistListModel::clear() {
     this->beginRemoveRows(QModelIndex(), 0, this->rowCount() - 1);
     m_list.clear();
     this->endRemoveRows();
     this->setLoading(false);
-    this->setOffset(1);
+    this->setOffset(0);
     this->setMoreResults(true);
     this->setError(false);
 }
