@@ -43,6 +43,9 @@ public:
 public:
     explicit PlaylistListModel(QObject *parent = 0);
     ~PlaylistListModel();
+#if QT_VERSION >= 0x050000
+    QHash<int, QByteArray> roleNames() const;
+#endif
     inline QUrl feed() const { return m_feed; }
     void setFeed(const QUrl &feed);
     inline bool loading() const { return m_loading; }
@@ -104,6 +107,9 @@ private:
     bool m_error;
     int m_offset;
     QList< QSharedPointer<PlaylistItem> > m_list;
+#if QT_VERSION >= 0x040600
+    QHash<int, QByteArray> m_roleNames;
+#endif
 };
 
 #endif // PLAYLISTLISTMODEL_H
