@@ -1,4 +1,5 @@
 #include "session.h"
+#include "networkaccessmanager.h"
 #include "settings.h"
 #include "database.h"
 #include "playbacklistmodel.h"
@@ -16,13 +17,15 @@
 #if (defined (MEDIA_PLAYERS_ENABLED)) && (defined (QML_USER_INTERFACE))
 #include "tracklauncher.h"
 #endif
-#include <QNetworkAccessManager>
+#ifdef IN_APP_UPDATES
+#include "../updatemanager/updatemanager.h"
+#endif
 
-Session* Session::m_instance = 0;
+Session* Session::self = 0;
 
 Session::Session(QObject *parent) :
     QObject(parent),
-    m_nam(new QNetworkAccessManager(this)),
+    m_nam(new NetworkAccessManager(this)),
     m_settings(new Settings(this)),
     m_database(new Database),
   #if (defined (MEDIA_PLAYERS_ENABLED)) && (defined (QML_USER_INTERFACE))
@@ -40,9 +43,12 @@ Session::Session(QObject *parent) :
   ,m_stack(new WindowStack(this))
   #endif
   #endif
+  #ifdef IN_APP_UPDATES
+  ,m_updateManager(new UpdateManager(this))
+  #endif
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 
     this->connect(m_soundcloud, SIGNAL(signedIn(QString)), m_database, SLOT(storeSoundCloudToken(QString)));
@@ -71,6 +77,13 @@ Session::Session(QObject *parent) :
     this->connect(m_soundcloud, SIGNAL(busyProgressChanged(int)), m_notifications, SLOT(updateProgressDialog(int)));
     this->connect(m_lastfm, SIGNAL(busy(QString,int)), m_notifications, SLOT(showProgressDialog(QString,int)));
     this->connect(m_lastfm, SIGNAL(busyProgressChanged(int)), m_notifications, SLOT(updateProgressDialog(int)));
+#ifdef IN_APP_UPDATES
+    this->connect(m_updateManager, SIGNAL(alert(QString)), m_notifications, SLOT(onAlert(QString)));
+    this->connect(m_updateManager, SIGNAL(error(QString)), m_notifications, SLOT(onError(QString)));
+    this->connect(m_updateManager, SIGNAL(info(QString)), m_notifications, SLOT(onInfo(QString)));
+    this->connect(m_updateManager, SIGNAL(busy(QString,int)), m_notifications, SLOT(showProgressDialog(QString,int)));
+    this->connect(m_updateManager, SIGNAL(busyProgressChanged(int)), m_notifications, SLOT(updateProgressDialog(int)));
+#endif
 
 #if (!defined (QML_USER_INTERFACE)) && (defined (Q_WS_MAEMO_5))
     this->connect(m_database, SIGNAL(alert(QString)), m_notifications, SLOT(cancelProgressDialog()));
@@ -85,11 +98,20 @@ Session::Session(QObject *parent) :
     this->connect(m_lastfm, SIGNAL(error(QString)), m_notifications, SLOT(cancelProgressDialog()));
     this->connect(m_lastfm, SIGNAL(info(QString)), m_notifications, SLOT(cancelProgressDialog()));
     this->connect(m_lastfm, SIGNAL(currentOperationCancelled()), m_notifications, SLOT(cancelProgressDialog()));
+#ifdef IN_APP_UPDATES
+    this->connect(m_updateManager, SIGNAL(alert(QString)), m_notifications, SLOT(cancelProgressDialog()));
+    this->connect(m_updateManager, SIGNAL(error(QString)), m_notifications, SLOT(cancelProgressDialog()));
+    this->connect(m_updateManager, SIGNAL(info(QString)), m_notifications, SLOT(cancelProgressDialog()));
+    this->connect(m_updateManager, SIGNAL(currentOperationCancelled()), m_notifications, SLOT(cancelProgressDialog()));
+#endif
 #endif
 
     m_soundcloud->setNetworkAccessManager(this->networkAccessManager());
     m_lastfm->setNetworkAccessManager(this->networkAccessManager());
     m_transferManager->setNetworkAccessManager(this->networkAccessManager());
+#ifdef IN_APP_UPDATES
+    m_updateManager->setNetworkAccessManager(this->networkAccessManager());
+#endif
     m_settings->restoreSettings();
     m_database->restoreAccounts();
 #ifndef QML_USER_INTERFACE
@@ -107,5 +129,5 @@ Session::~Session() {
 }
 
 Session* Session::instance() {
-    return !m_instance ? new Session : m_instance;
+    return !self ? new Session : self;
 }
