@@ -21,6 +21,9 @@ class WindowStack;
 #if (defined (MEDIA_PLAYERS_ENABLED)) && (defined (QML_USER_INTERFACE))
 class TrackLauncher;
 #endif
+#ifdef IN_APP_UPDATES
+class UpdateManager;
+#endif
 
 class Session : public QObject
 {
@@ -34,7 +37,7 @@ public:
     static Session* instance();
     
 private:
-    static Session *m_instance;
+    static Session *self;
     QNetworkAccessManager *m_nam;
     Settings *m_settings;
     Database *m_database;
@@ -53,6 +56,9 @@ private:
     WindowStack *m_stack;
 #endif
 #endif
+#ifdef IN_APP_UPDATES
+    UpdateManager *m_updateManager;
+#endif
 };
 
 #endif // SESSION_H
