@@ -1,8 +1,13 @@
 #include "settings.h"
 #include <QDir>
+#include <QAuthenticator>
+#if QT_VERSION >= 0x050000
+#include <QStandardPaths>
+#else
 #include <QDesktopServices>
+#endif
 
-Settings* Settings::m_instance = 0;
+Settings* Settings::self = 0;
 
 Settings::Settings(QObject *parent) :
     QSettings(QString("MusiKloud"), QString("MusiKloud"), parent),
@@ -12,25 +17,30 @@ Settings::Settings(QObject *parent) :
     m_maxConcurrentTransfers(1),
     m_searchOrder(Queries::Hotness),
     m_searchType(Queries::Tracks),
-  #if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
+    #if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
     m_activeColor("#0881cb"),
     m_activeColorString("color7"),
-  #endif
+    #endif
     m_language("en"),
-  #ifdef MEDIA_PLAYERS_ENABLED
+    #ifdef MEDIA_PLAYERS_ENABLED
     m_mediaplayer("musikloud"),
-  #endif
-  #ifndef SYMBIAN_OS
+    #endif
+    #ifndef SYMBIAN_OS
     m_monitorClipboard(false),
-  #endif
-    m_orientation(ScreenOrientation::Automatic)
+    #endif
+    m_orientation(ScreenOrientation::Automatic),
+    m_proxyType(NetworkProxyType::HttpProxy),
+    m_proxyPort(80)
   #ifdef Q_WS_MAEMO_5
-    ,m_eventFeedEnabled(false),
+  ,m_eventFeedEnabled(false),
     m_eventFeedInstalled(false)
   #endif
+  #ifdef IN_APP_UPDATES
+  ,m_checkUpdate(false)
+  #endif
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 }
 
@@ -39,7 +49,7 @@ Settings::~Settings() {
 }
 
 Settings* Settings::instance() {
-    return !m_instance ? new Settings : m_instance;
+    return !self ? new Settings : self;
 }
 
 void Settings::restoreSettings() {
@@ -50,6 +60,8 @@ void Settings::restoreSettings() {
     this->setDownloadPath(this->value("downloadPath", QString("/home/user/MyDocs/MusiKloud/")).toString());
 #elif defined (SYMBIAN_OS)
     this->setDownloadPath(this->value("downloadPath", QString("E:/MusiKloud/")).toString());
+#elif QT_VERSION >= 0x050000
+    this->setDownloadPath(this->value("downloadPath", QStandardPaths::writableLocation(QStandardPaths::MusicLocation).append("/MusiKloud/")).toString());
 #else
     this->setDownloadPath(this->value("downloadPath", QDesktopServices::storageLocation(QDesktopServices::MusicLocation).append("/MusiKloud/")).toString());
 #endif
@@ -89,8 +101,17 @@ void Settings::restoreSettings() {
     this->beginGroup("System");
     this->setLanguage(this->value("language", QString("en")).toString());
     this->setScreenOrientation(static_cast<ScreenOrientation::Orientation>(this->value("screenOrientation", ScreenOrientation::Automatic).toInt()));
+    this->setNetworkProxyType(static_cast<NetworkProxyType::ProxyType>(this->value("networkProxyType", NetworkProxyType::ProxyType(NetworkProxyType::HttpProxy)).toInt()));
+    this->setNetworkProxyHostName(this->value("networkProxyHostName", QString()).toString());
+    this->setNetworkProxyPort(this->value("networkProxyPort", 80).toUInt());
+    this->setNetworkProxyUser(this->value("networkProxyUser", QString()).toString());
+    this->setNetworkProxyPassword(QString(QByteArray::fromBase64(this->value("networkProxyPassword", QByteArray()).toByteArray())));
+    this->setNetworkProxy();
 #ifndef SYMBIAN_OS
     this->setMonitorClipboard(this->value("monitorClipboard", false).toBool());
+#endif
+#ifdef IN_APP_UPDATES
+    this->setCheckForUpdateOnStartup(this->value("checkForUpdateOnStartup", false).toBool());
 #endif
     this->endGroup();
 }
@@ -136,8 +157,16 @@ void Settings::saveSettings() {
     this->beginGroup("System");
     this->setValue("language", this->language());
     this->setValue("screenOrientation", ScreenOrientation::Orientation(this->screenOrientation()));
+    this->setValue("networkProxyType", NetworkProxyType::ProxyType(this->networkProxyType()));
+    this->setValue("networkProxyHostName", this->networkProxyHostName());
+    this->setValue("networkProxyPort", this->networkProxyPort());
+    this->setValue("networkProxyUser", this->networkProxyUser());
+    this->setValue("networkProxyPassword", this->networkProxyPassword().toUtf8().toBase64());
 #ifndef SYMBIAN_OS
     this->setValue("monitorClipboard", this->monitorClipboard());
+#endif
+#ifdef IN_APP_UPDATES
+    this->setValue("checkForUpdateOnStartup", this->checkForUpdateOnStartup());
 #endif
     this->endGroup();
 }
@@ -275,6 +304,71 @@ void Settings::setScreenOrientation(ScreenOrientation::Orientation orientation)
     }
 }
 
+void Settings::setNetworkProxyType(NetworkProxyType::ProxyType proxyType) {
+    if (proxyType != this->networkProxyType()) {
+        m_proxyType = proxyType;
+        emit networkProxyTypeChanged(proxyType);
+    }
+}
+
+void Settings::setNetworkProxyHostName(const QString &hostName) {
+    if (hostName != this->networkProxyHostName()) {
+        m_proxyHost = hostName;
+        emit networkProxyHostNameChanged(hostName);
+    }
+}
+
+void Settings::setNetworkProxyPort(quint16 port) {
+    if (port != this->networkProxyPort()) {
+        m_proxyPort = port;
+        emit networkProxyPortChanged(port);
+    }
+}
+
+void Settings::setNetworkProxyUser(const QString &user) {
+    if (user != this->networkProxyUser()) {
+        m_proxyUser = user;
+        emit networkProxyUserChanged(user);
+    }
+}
+
+void Settings::setNetworkProxyPassword(const QString &password) {
+    if (password != this->networkProxyPassword()) {
+        m_proxyPass = password;
+        emit networkProxyPasswordChanged(password);
+    }
+}
+
+void Settings::setNetworkProxy() {
+    QNetworkProxy proxy;
+
+    if (!this->networkProxyHostName().isEmpty()) {
+        proxy.setHostName(this->networkProxyHostName());
+        proxy.setType(QNetworkProxy::ProxyType(this->networkProxyType()));
+
+        if (this->networkProxyPort() > 0) {
+            proxy.setPort(this->networkProxyPort());
+        }
+        else {
+            proxy.setPort(80);
+        }
+
+        if ((!this->networkProxyUser().isEmpty()) && (!this->networkProxyPassword().isEmpty())) {
+            proxy.setUser(this->networkProxyUser());
+            proxy.setPassword(this->networkProxyPassword());
+        }
+    }
+
+    QNetworkProxy::setApplicationProxy(proxy);
+}
+
+void Settings::onNetworkProxyAuthenticationRequested(const QNetworkProxy &proxy, QAuthenticator *authenticator) {
+    Q_UNUSED(proxy)
+
+    authenticator->setUser(this->networkProxyUser());
+    authenticator->setPassword(this->networkProxyPassword());
+}
+
 #ifdef Q_WS_MAEMO_5
 void Settings::setEventFeedEnabled(bool enabled) {
     if (enabled != this->eventFeedEnabled()) {
@@ -288,3 +382,12 @@ bool Settings::eventFeedInstalled() const {
 
 }
 #endif
+
+#ifdef IN_APP_UPDATES
+void Settings::setCheckForUpdateOnStartup(bool check) {
+    if (check != this->checkForUpdateOnStartup()) {
+        m_checkUpdate = check;
+        emit checkForUpdateOnStartupChanged(check);
+    }
+}
+#endif
