@@ -6,6 +6,9 @@
 #include <QStringList>
 #include <qplatformdefs.h>
 
+class QNetworkProxy;
+class QAuthenticator;
+
 class Settings : public QSettings
 {
     Q_OBJECT
@@ -50,7 +53,7 @@ class Settings : public QSettings
 #if (defined (SYMBIAN_OS) || (defined (MEEGO_EDITION_HARMATTAN)))
     Q_PROPERTY(QString activeColor
                READ activeColor
-#ifdef SYMBIAN_OS
+           #ifdef SYMBIAN_OS
                CONSTANT)
 #else
                WRITE setActiveColor
@@ -58,7 +61,7 @@ class Settings : public QSettings
 #endif
     Q_PROPERTY(QString activeColorString
                READ activeColorString
-#ifdef SYMBIAN_OS
+           #ifdef SYMBIAN_OS
                CONSTANT)
 #else
                WRITE setActiveColorString
@@ -69,10 +72,6 @@ class Settings : public QSettings
                READ language
                WRITE setLanguage
                NOTIFY languageChanged)
-    Q_PROPERTY(ScreenOrientation::Orientation screenOrientation
-               READ screenOrientation
-               WRITE setScreenOrientation
-               NOTIFY screenOrientationChanged)
 #ifdef MEDIA_PLAYERS_ENABLED
     Q_PROPERTY(QString mediaPlayer
                READ mediaPlayer
@@ -91,6 +90,30 @@ class Settings : public QSettings
                WRITE setMonitorClipboard
                NOTIFY monitorClipboardChanged)
 #endif
+    Q_PROPERTY(ScreenOrientation::Orientation screenOrientation
+               READ screenOrientation
+               WRITE setScreenOrientation
+               NOTIFY screenOrientationChanged)
+    Q_PROPERTY(NetworkProxyType::ProxyType networkProxyType
+               READ networkProxyType
+               WRITE setNetworkProxyType
+               NOTIFY networkProxyTypeChanged)
+    Q_PROPERTY(QString networkProxyHostName
+               READ networkProxyHostName
+               WRITE setNetworkProxyHostName
+               NOTIFY networkProxyHostNameChanged)
+    Q_PROPERTY(quint16 networkProxyPort
+               READ networkProxyPort
+               WRITE setNetworkProxyPort
+               NOTIFY networkProxyPortChanged)
+    Q_PROPERTY(QString networkProxyUser
+               READ networkProxyUser
+               WRITE setNetworkProxyUser
+               NOTIFY networkProxyUserChanged)
+    Q_PROPERTY(QString networkProxyPassword
+               READ networkProxyPassword
+               WRITE setNetworkProxyPassword
+               NOTIFY networkProxyPasswordChanged)
 #ifdef Q_WS_MAEMO_5
     Q_PROPERTY(bool eventFeedEnabled
                READ eventFeedEnabled
@@ -100,6 +123,12 @@ class Settings : public QSettings
                READ eventFeedInstalled
                CONSTANT)
 #endif
+#ifdef IN_APP_UPDATES
+    Q_PROPERTY(bool checkForUpdateOnStartup
+               READ checkForUpdateOnStartup
+               WRITE setCheckForUpdateOnStartup
+               NOTIFY checkForUpdateOnStartupChanged)
+#endif
 #endif
 
 public:
@@ -129,10 +158,18 @@ public:
     inline bool monitorClipboard() const { return m_monitorClipboard; }
 #endif
     inline ScreenOrientation::Orientation screenOrientation() const { return m_orientation; }
+    inline NetworkProxyType::ProxyType networkProxyType() const { return m_proxyType; }
+    inline QString networkProxyHostName() const { return m_proxyHost; }
+    inline quint16 networkProxyPort() const { return m_proxyPort; }
+    inline QString networkProxyUser() const { return m_proxyUser; }
+    inline QString networkProxyPassword() const { return m_proxyPass; }
 #ifdef Q_WS_MAEMO_5
     inline bool eventFeedEnabled() const { return m_eventFeedEnabled; }
     bool eventFeedInstalled() const;
 #endif
+#ifdef IN_APP_UPDATES
+    inline bool checkForUpdateOnStartup() const { return m_checkUpdate; }
+#endif
 
     static Settings* instance();
 
@@ -161,11 +198,23 @@ public slots:
 #endif
 #ifndef SYMBIAN_OS
     void setMonitorClipboard(bool monitor);
-#endif
+#endif    
     void setScreenOrientation(ScreenOrientation::Orientation orientation);
+    void setNetworkProxyType(NetworkProxyType::ProxyType proxyType);
+    void setNetworkProxyHostName(const QString &hostName);
+    void setNetworkProxyPort(quint16 port);
+    void setNetworkProxyUser(const QString &user);
+    void setNetworkProxyPassword(const QString &password);
+    void setNetworkProxy();
 #ifdef Q_WS_MAEMO_5
     void setEventFeedEnabled(bool enabled);
 #endif
+#ifdef IN_APP_UPDATES
+    void setCheckForUpdateOnStartup(bool check);
+#endif
+
+private slots:
+    void onNetworkProxyAuthenticationRequested(const QNetworkProxy &proxy, QAuthenticator *authenticator);
 
 signals:
     void scrobbleTracksChanged(bool scrobble);
@@ -193,10 +242,20 @@ signals:
     void monitorClipboardChanged(bool monitor);
 #endif
     void screenOrientationChanged(ScreenOrientation::Orientation orientation);
+    void networkProxyTypeChanged(NetworkProxyType::ProxyType proxyType);
+    void networkProxyHostNameChanged(const QString &hostName);
+    void networkProxyPortChanged(quint16 port);
+    void networkProxyUserChanged(const QString &user);
+    void networkProxyPasswordChanged(const QString &password);
+#ifdef Q_WS_MAEMO_5
     void eventFeedEnabledChanged(bool enabled);
+#endif
+#ifdef IN_APP_UPDATES
+    void checkForUpdateOnStartupChanged(bool check);
+#endif
 
 private:
-    static Settings* m_instance;
+    static Settings* self;
     bool m_scrobble;
     bool m_archiveOnline;
     AudioFormats::Format m_downloadFormat;
@@ -221,10 +280,18 @@ private:
     bool m_monitorClipboard;
 #endif
     ScreenOrientation::Orientation m_orientation;
+    NetworkProxyType::ProxyType m_proxyType;
+    QString m_proxyHost;
+    quint16 m_proxyPort;
+    QString m_proxyUser;
+    QString m_proxyPass;
 #ifdef Q_WS_MAEMO_5
     bool m_eventFeedEnabled;
     bool m_eventFeedInstalled;
 #endif
+#ifdef IN_APP_UPDATES
+    bool m_checkUpdate;
+#endif
 };
 
 #endif // SETTINGS_H
