@@ -10,14 +10,21 @@
 #include <QUrl>
 #include <QDebug>
 #ifdef QML_USER_INTERFACE
+#if QT_VERSION >= 0x050000
+#include <QQmlEngine>
+#else
 #include <QDeclarativeEngine>
 #endif
+#endif
+#if QT_VERSION >= 0x050000
+#include <QUrlQuery>
+#endif
 
 const QString CLIENT_ID("aada80a82c91fb42d0bb1cb321b59034");
 const QString CLIENT_SECRET("dcc9c80ce05614d4988cebb82ddde152");
 const QString REDIRECT_URI("http://www.musikloud.co.uk");
 
-SoundCloud* SoundCloud::m_instance = 0;
+SoundCloud* SoundCloud::self = 0;
 
 using namespace QtJson;
 
@@ -27,15 +34,15 @@ SoundCloud::SoundCloud(QObject *parent) :
     m_busy(false),
     m_cancelled(false)
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 }
 
 SoundCloud::~SoundCloud() {}
 
 SoundCloud* SoundCloud::instance() {
-    return !m_instance ? new SoundCloud : m_instance;
+    return !self ? new SoundCloud : self;
 }
 
 void SoundCloud::setBusy(bool isBusy, const QString &message, int numberOfOperations) {
@@ -72,16 +79,43 @@ void SoundCloud::cancelCurrentOperation() {
 
 QUrl SoundCloud::authUrl() {
     QUrl url("https://soundcloud.com/connect");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("client_id", CLIENT_ID);
+    query.addQueryItem("response_type", "code");
+    query.addQueryItem("redirect_uri", REDIRECT_URI);
+    query.addQueryItem("scope", "non-expiring");
+    query.addQueryItem("display", "popup");
+    url.setQuery(query);
+#else
     url.addQueryItem("client_id", CLIENT_ID);
     url.addQueryItem("response_type", "code");
     url.addQueryItem("redirect_uri", REDIRECT_URI);
     url.addQueryItem("scope", "non-expiring");
     url.addQueryItem("display", "popup");
-
+#endif
     return url;
 }
 
 QNetworkReply* SoundCloud::createReply(QUrl url, int offset) {
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+
+    if (this->userSignedIn()) {
+        url.setScheme("https");
+        query.addQueryItem("oauth_token", this->accessToken());
+    }
+    else {
+        url.setScheme("http");
+        query.addQueryItem("client_id", CLIENT_ID);
+    }
+
+    if (offset) {
+        query.addQueryItem("offset", QString::number(offset));
+    }
+
+    url.setQuery(query);
+#else
     if (this->userSignedIn()) {
         url.setScheme("https");
         url.addQueryItem("oauth_token", this->accessToken());
@@ -94,7 +128,7 @@ QNetworkReply* SoundCloud::createReply(QUrl url, int offset) {
     if (offset) {
         url.addQueryItem("offset", QString::number(offset));
     }
-
+#endif
     qDebug() << url;
 
     QNetworkRequest request(url);
@@ -126,7 +160,27 @@ QNetworkReply* SoundCloud::createSearchReply(int queryType, const QString &query
         qWarning() << "SoundCloud::createSearchReply(): Invalid query type.";
         break;
     }
+#if QT_VERSION >= 0x050000
+    QUrlQuery urlQuery(url);
 
+    switch (order) {
+    case Queries::Date:
+        urlQuery.addQueryItem("order", "created_at");
+        break;
+    default:
+        urlQuery.addQueryItem("order", "hotness");
+        break;
+    }
+
+    urlQuery.addQueryItem("q", "'" + query + "'|" + qs);
+    urlQuery.addQueryItem("client_id", CLIENT_ID);
+
+    if (offset) {
+        urlQuery.addQueryItem("offset", QString::number(offset));
+    }
+
+    url.setQuery(urlQuery);
+#else
     switch (order) {
     case Queries::Date:
         url.addQueryItem("order", "created_at");
@@ -142,7 +196,7 @@ QNetworkReply* SoundCloud::createSearchReply(int queryType, const QString &query
     if (offset) {
         url.addQueryItem("offset", QString::number(offset));
     }
-
+#endif
     qDebug() << url;
 
     QNetworkRequest request(url);
@@ -155,14 +209,41 @@ QUrl SoundCloud::getStreamUrl(QUrl url) {
     if (url.scheme() == "https") {
         url.setScheme("http");
     }
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+
+    if (!query.hasQueryItem("client_id")) {
+        query.addQueryItem("client_id", CLIENT_ID);
+    }
+
+    url.setQuery(query);
+#else
     if (!url.hasQueryItem("client_id")) {
         url.addQueryItem("client_id", CLIENT_ID);
     }
-
+#endif
     return url;
 }
 
 QUrl SoundCloud::getDownloadUrl(QUrl url) {
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(url);
+
+    if (url.scheme() == "https") {
+        if (this->userSignedIn()) {
+            query.addQueryItem("oauth_token", this->accessToken());
+        }
+        else {
+            url.setScheme("http");
+            query.addQueryItem("client_id", CLIENT_ID);
+        }
+    }
+    else {
+        query.addQueryItem("client_id", CLIENT_ID);
+    }
+
+    url.setQuery(query);
+#else
     if (url.scheme() == "https") {
         if (this->userSignedIn()) {
             url.addQueryItem("oauth_token", this->accessToken());
@@ -175,15 +256,22 @@ QUrl SoundCloud::getDownloadUrl(QUrl url) {
     else {
         url.addQueryItem("client_id", CLIENT_ID);
     }
-
+#endif
     return url;
 }
 
 void SoundCloud::resolve(const QString &urlToResolve) {
     this->setBusy(true, tr("Resolving URL"));
     QUrl url("https://api.soundcloud.com/resolve");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("url", urlToResolve);
+    query.addQueryItem("client_id", CLIENT_ID);
+    url.setQuery(query);
+#else
     url.addQueryItem("url", urlToResolve);
     url.addQueryItem("client_id", CLIENT_ID);
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("MusiKloud/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -238,7 +326,20 @@ void SoundCloud::getFullTrack(const QString &id) {
     }
 
     QUrl url;
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
 
+    if (this->userSignedIn()) {
+        url.setUrl("https://api.soundcloud.com/tracks/" + id + ".json");
+        query.addQueryItem("oauth_token", this->accessToken());
+    }
+    else {
+        url.setUrl("http://api.soundcloud.com/tracks/" + id + ".json");
+        query.addQueryItem("client_id", CLIENT_ID);
+    }
+
+    url.setQuery(query);
+#else
     if (this->userSignedIn()) {
         url.setUrl("https://api.soundcloud.com/tracks/" + id + ".json");
         url.addQueryItem("oauth_token", this->accessToken());
@@ -247,7 +348,7 @@ void SoundCloud::getFullTrack(const QString &id) {
         url.setUrl("http://api.soundcloud.com/tracks/" + id + ".json");
         url.addQueryItem("client_id", CLIENT_ID);
     }
-
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("MusiKloud/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -281,7 +382,11 @@ void SoundCloud::checkTrack() {
     else {
         TrackItem *track = new TrackItem(result);
 #ifdef QML_USER_INTERFACE
+#if QT_VERSION >= 0x050000
+        QQmlEngine::setObjectOwnership(track, QQmlEngine::JavaScriptOwnership);
+#else
         QDeclarativeEngine::setObjectOwnership(track, QDeclarativeEngine::JavaScriptOwnership);
+#endif
         emit gotTrack(track);
 #else
         emit gotTrack(QSharedPointer<TrackItem>(track));
@@ -305,7 +410,20 @@ void SoundCloud::getFullPlaylist(const QString &id) {
     }
 
     QUrl url;
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
 
+    if (this->userSignedIn()) {
+        url.setUrl("https://api.soundcloud.com/playlists/" + id + ".json");
+        query.addQueryItem("oauth_token", this->accessToken());
+    }
+    else {
+        url.setUrl("http://api.soundcloud.com/playlists/" + id + ".json");
+        query.addQueryItem("client_id", CLIENT_ID);
+    }
+
+    url.setQuery(query);
+#else
     if (this->userSignedIn()) {
         url.setUrl("https://api.soundcloud.com/playlists/" + id + ".json");
         url.addQueryItem("oauth_token", this->accessToken());
@@ -314,7 +432,7 @@ void SoundCloud::getFullPlaylist(const QString &id) {
         url.setUrl("http://api.soundcloud.com/playlists/" + id + ".json");
         url.addQueryItem("client_id", CLIENT_ID);
     }
-
+#endif
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("MusiKloud/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -348,7 +466,11 @@ void SoundCloud::checkPlaylist() {
     else {
         PlaylistItem *playlist = new PlaylistItem(result);
 #ifdef QML_USER_INTERFACE
+#if QT_VERSION >= 0x050000
+        QQmlEngine::setObjectOwnership(playlist, QQmlEngine::JavaScriptOwnership);
+#else
         QDeclarativeEngine::setObjectOwnership(playlist, QDeclarativeEngine::JavaScriptOwnership);
+#endif
         emit gotPlaylist(playlist);
 #else
         emit gotPlaylist(QSharedPointer<PlaylistItem>(playlist));
@@ -363,8 +485,7 @@ void SoundCloud::checkPlaylist() {
 }
 
 void SoundCloud::getUserProfile(const QString &id) {
-    QUrl url(QString("http://api.soundcloud.com/users/%1.json").arg(id));
-    url.addQueryItem("client_id", CLIENT_ID);
+    QUrl url(QString("http://api.soundcloud.com/users/%1.json?client_id=%2").arg(id).arg(CLIENT_ID));
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("MusiKloud/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -400,7 +521,11 @@ void SoundCloud::checkUser() {
             this->isUserFollowed(user->id());
         }
 #ifdef QML_USER_INTERFACE
+#if QT_VERSION >= 0x050000
+        QQmlEngine::setObjectOwnership(user, QQmlEngine::JavaScriptOwnership);
+#else
         QDeclarativeEngine::setObjectOwnership(user, QDeclarativeEngine::JavaScriptOwnership);
+#endif
         emit gotUser(user);
 #else
         emit gotUser(QSharedPointer<UserItem>(user));
@@ -415,8 +540,7 @@ void SoundCloud::checkUser() {
 }
 
 void SoundCloud::getCurrentUserProfile() {
-    QUrl url("https://api.soundcloud.com/me.json");
-    url.addQueryItem("oauth_token", this->accessToken());
+    QUrl url("https://api.soundcloud.com/me.json?oauth_token=" + this->accessToken());
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("MusiKloud/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -457,7 +581,11 @@ void SoundCloud::checkCurrentUser() {
         emit gotUsername(user->username());
     }
 #ifdef QML_USER_INTERFACE
-    QDeclarativeEngine::setObjectOwnership(user, QDeclarativeEngine::JavaScriptOwnership);
+#if QT_VERSION >= 0x050000
+        QQmlEngine::setObjectOwnership(user, QQmlEngine::JavaScriptOwnership);
+#else
+        QDeclarativeEngine::setObjectOwnership(user, QDeclarativeEngine::JavaScriptOwnership);
+#endif
     emit gotUser(user);
 #else
     emit gotUser(QSharedPointer<UserItem>(user));
@@ -467,8 +595,7 @@ void SoundCloud::checkCurrentUser() {
 
 void SoundCloud::isUserFollowed(const QString &id) {
     m_actionId = id;
-    QUrl url(QString("https://api.soundcloud.com/me/followings/%1.json").arg(id));
-    url.addQueryItem("oauth_token", this->accessToken());
+    QUrl url(QString("https://api.soundcloud.com/me/followings/%1.json?oauth_token=%2").arg(id).arg(this->accessToken()));
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("MusiKloud/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -489,8 +616,7 @@ void SoundCloud::checkIfUserFollowed() {
 
 void SoundCloud::trackIsFavourite(const QString &id) {
     m_actionId = id;
-    QUrl url(QString("https://api.soundcloud.com/me/favorites/%1.json").arg(id));
-    url.addQueryItem("oauth_token", this->accessToken());
+    QUrl url(QString("https://api.soundcloud.com/me/favorites/%1.json?oauth_token=%2").arg(id).arg(this->accessToken()));
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("MusiKloud/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
@@ -510,7 +636,28 @@ void SoundCloud::checkIfFavourite() {
 }
 
 void SoundCloud::signIn(const QUrl &response) {
-    QByteArray authCode = response.encodedQueryItemValue("code");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query(response);
+    QString authCode = query.queryItemValue("code");
+
+    if (authCode.isEmpty()) {
+
+        QString errorString = query.queryItemValue("error");
+
+        if (errorString == "access_denied") {
+            emit info(tr("You have denied access to your SoundCloud account"));
+        }
+        else if (errorString.isEmpty()){
+            emit error(tr("No authorisation code received from SoundCloud"));
+        }
+        else {
+            emit error(query.queryItemValue("error_description").replace('+', ' '));
+        }
+
+        return;
+    }
+#else
+    QString authCode = response.queryItemValue("code");
 
     if (authCode.isEmpty()) {
 
@@ -528,7 +675,7 @@ void SoundCloud::signIn(const QUrl &response) {
 
         return;
     }
-
+#endif
     this->setBusy(true, tr("Signing in"));
     QNetworkRequest request(QUrl("https://api.soundcloud.com/oauth2/token"));
     QByteArray data(
@@ -536,7 +683,7 @@ void SoundCloud::signIn(const QUrl &response) {
                 + "&client_secret=" + CLIENT_SECRET.toUtf8()
                 + "&redirect_uri=" + REDIRECT_URI.toUtf8()
                 + "&grant_type=authorization_code"
-                + "&code=" + authCode
+                + "&code=" + authCode.toUtf8()
                 );
 
     request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
@@ -673,8 +820,7 @@ void SoundCloud::postFinished() {
 }
 
 void SoundCloud::addComment(const QString &id, const QString &comment, int timestamp) {
-    QUrl url(QString("https://api.soundcloud.com/tracks/%1/comments.json").arg(id));
-    url.addQueryItem("oauth_token", this->accessToken());
+    QUrl url(QString("https://api.soundcloud.com/tracks/%1/comments.json?oauth_token=%2").arg(id).arg(this->accessToken()));
     QByteArray data("&comment[body]=" + comment.toUtf8().toPercentEncoding());
 
     if (timestamp) {
@@ -710,8 +856,7 @@ void SoundCloud::addToFavourites(const QStringList &ids) {
 
 void SoundCloud::addToFavourites() {
     if (!m_actionIds.isEmpty()) {
-        QUrl url(QString("https://api.soundcloud.com/me/favorites/%1.json").arg(m_actionIds.first()));
-        url.addQueryItem("oauth_token", this->accessToken());
+        QUrl url(QString("https://api.soundcloud.com/me/favorites/%1.json?oauth_token=%2").arg(m_actionIds.first()).arg(this->accessToken()));
         this->putRequest(url);
         this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onAddedToFavourites()));
         this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onTrackActionError(QString)));
@@ -748,8 +893,7 @@ void SoundCloud::deleteFromFavourites(const QStringList &ids) {
 
 void SoundCloud::deleteFromFavourites() {
     if (!m_actionIds.isEmpty()) {
-        QUrl url(QString("https://api.soundcloud.com/me/favorites/%1.json").arg(m_actionIds.first()));
-        url.addQueryItem("oauth_token", this->accessToken());
+        QUrl url(QString("https://api.soundcloud.com/me/favorites/%1.json?oauth_token=%2").arg(m_actionIds.first()).arg(this->accessToken()));
         this->deleteRequest(url);
         this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onDeletedFromFavourites()));
         this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onTrackActionError(QString)));
@@ -785,8 +929,7 @@ void SoundCloud::onTrackActionError(const QString &errorString) {
 
 void SoundCloud::followUser(const QString &id) {
     m_actionId = id;
-    QUrl url(QString("https://api.soundcloud.com/me/followings/%1.json").arg(id));
-    url.addQueryItem("oauth_token", this->accessToken());
+    QUrl url(QString("https://api.soundcloud.com/me/followings/%1.json?oauth_token=%2").arg(id).arg(this->accessToken()));
     this->putRequest(url);
     this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onUserFollowed()));
     this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onUserActionError(QString)));
@@ -801,8 +944,7 @@ void SoundCloud::onUserFollowed() {
 
 void SoundCloud::unfollowUser(const QString &id) {
     m_actionId = id;
-    QUrl url(QString("https://api.soundcloud.com/me/followings/%1.json").arg(id));
-    url.addQueryItem("oauth_token", this->accessToken());
+    QUrl url(QString("https://api.soundcloud.com/me/followings/%1.json?oauth_token=%2").arg(id).arg(this->accessToken()));
     this->deleteRequest(url);
     this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onUserUnfollowed()));
     this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onUserActionError(QString)));
@@ -823,12 +965,23 @@ void SoundCloud::onUserActionError(const QString &errorString) {
 
 void SoundCloud::updateProfile(const QVariantMap &profile) {
     QUrl url("https://api.soundcloud.com/me.json");
+#if QT_VERSION >= 0x050000
+    QUrlQuery query;
+    query.addQueryItem("oauth_token", this->accessToken());
+    query.addQueryItem("user[full_name]", profile.value("fullname").toString());
+    query.addQueryItem("user[discogs_name]", profile.value("bandname").toString());
+    query.addQueryItem("user[website]", profile.value("websiteUrl").toString());
+    query.addQueryItem("user[website_name]", profile.value("websiteTitle").toString());
+    query.addQueryItem("user[description]", profile.value("description").toString());
+    url.setQuery(query);
+#else
     url.addQueryItem("oauth_token", this->accessToken());
     url.addQueryItem("user[full_name]", profile.value("fullname").toString());
     url.addQueryItem("user[discogs_name]", profile.value("bandname").toString());
     url.addQueryItem("user[website]", profile.value("websiteUrl").toString());
     url.addQueryItem("user[website_name]", profile.value("websiteTitle").toString());
     url.addQueryItem("user[description]", profile.value("description").toString());
+#endif
     this->putRequest(url);
     this->connect(this, SIGNAL(postSuccessful(QString)), this, SLOT(onProfileUpdated(QString)));
     this->connect(this, SIGNAL(postFailed(QString)), this, SLOT(onUserActionError(QString)));
@@ -851,8 +1004,7 @@ void SoundCloud::onProfileUpdated(const QString &response) {
 }
 
 void SoundCloud::shareTrack(const QString &id, const QStringList &connections, const QString &message) {
-    QUrl url(QString("https://api.soundcloud.com/tracks/%1/shared-to/connections").arg(id));
-    url.addQueryItem("oauth_token", this->accessToken());
+    QUrl url(QString("https://api.soundcloud.com/tracks/%1/shared-to/connections?oauth_token=%2").arg(id).arg(this->accessToken()));
     QByteArray data(
                 "&connections[][id]=" + connections.join("[id]=").toUtf8()
                 + "&sharing_note=" + message.toUtf8().toPercentEncoding(QByteArray("+"))
