@@ -157,7 +157,7 @@ signals:
 #endif
 
 private:
-    static SoundCloud* m_instance;
+    static SoundCloud* self;
     QNetworkAccessManager *m_nam;
     QString m_username;
     QString m_accessToken;
