@@ -35,7 +35,7 @@ signals:
     void downloadThumbnail(const QUrl &url);
 
 private:
-    static ThumbnailCache* m_instance;
+    static ThumbnailCache* self;
     QQueue<QUrl> m_urls;
 };
 
