@@ -11,6 +11,7 @@ class TrackItem : public QObject
 {
     Q_OBJECT
 
+#if QT_VERSION >= 0x040700
     Q_PROPERTY(QString id
                READ id
                NOTIFY idChanged)
@@ -101,7 +102,7 @@ class TrackItem : public QObject
     Q_PROPERTY(Services::AudioService service
                READ service
                NOTIFY serviceChanged)
-
+#endif
 
 public:
     explicit TrackItem(QObject *parent = 0);
