@@ -19,7 +19,7 @@ public slots:
     static void launchTracks(QList<QUrl> &urls);
 
 private:
-    static TrackLauncher* m_instance;
+    static TrackLauncher* self;
 };
 
 #endif // TRACKLAUNCHER_H
