@@ -5,7 +5,7 @@
 #include "playlistitem.h"
 #include "utils.h"
 
-TransferManager* TransferManager::m_instance = 0;
+TransferManager* TransferManager::self = 0;
 
 TransferManager::TransferManager(QObject *parent) :
     QObject(parent),
@@ -15,8 +15,8 @@ TransferManager::TransferManager(QObject *parent) :
   ,m_transferUI(new Client(this))
   #endif
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 #ifdef MEEGO_EDITION_HARMATTAN
     m_transferUI->init();
@@ -30,7 +30,7 @@ TransferManager::~TransferManager() {
 }
 
 TransferManager* TransferManager::instance() {
-    return !m_instance ? new TransferManager : m_instance;
+    return !self ? new TransferManager : self;
 }
 
 void TransferManager::restoreStoredDownloads() {
@@ -53,6 +53,8 @@ void TransferManager::restoreStoredDownloads() {
             transfer.data()->startTransfer();
         }
     }
+
+    emit countChanged(this->count());
 }
 
 QString TransferManager::generateTransferId(QString seedFileName) const {
@@ -79,6 +81,8 @@ void TransferManager::addDownloadTransfer(TrackItem *track, bool notify) {
     if (notify) {
         emit alert(tr("Track download added to transfer queue"));
     }
+
+    emit countChanged(this->count());
 }
 
 void TransferManager::addDownloadTransfer(QSharedPointer<TrackItem> track, bool notify) {
@@ -112,6 +116,8 @@ void TransferManager::addDownloadTransfer(PlaylistItem *playlist, QList<TrackIte
     if (notify) {
         emit alert(tr("Set download added to transfer queue"));
     }
+
+    emit countChanged(this->count());
 }
 
 void TransferManager::addDownloadTransfer(QSharedPointer<PlaylistItem> playlist, QList<QSharedPointer<TrackItem> > tracks, bool notify) {
@@ -141,6 +147,8 @@ void TransferManager::addDownloadTransfer(QSharedPointer<PlaylistItem> playlist,
     if (notify) {
         emit alert(tr("Set download added to transfer queue"));
     }
+
+    emit countChanged(this->count());
 }
 
 void TransferManager::addDownloadTransfers(QList<TrackItem *> tracks) {
@@ -208,6 +216,7 @@ bool TransferManager::removeTransfer(QSharedPointer<TransferItem> transfer) {
     if (row >= 0) {
         this->transferList()->removeAt(row);
         emit transferRemoved(row);
+        emit countChanged(this->count());
         return true;
     }
 
