@@ -7,6 +7,8 @@
 #ifdef MEEGO_EDITION_HARMATTAN
 #include "../harmattan/transferitem.h"
 #include <TransferUI/Client>
+#elif (defined (Q_WS_SAILFISH))
+#include "../maemo5/transferitem.h"
 #elif (defined (Q_WS_MAEMO_5))
 #include "../maemo5/transferitem.h"
 #elif (defined (Q_WS_MAEMO_4))
@@ -23,6 +25,12 @@ class TransferManager : public QObject
 {
     Q_OBJECT
 
+#if QT_VERSION >= 0x040600
+    Q_PROPERTY(int count
+               READ count
+               NOTIFY countChanged)
+#endif
+
 public:
     explicit TransferManager(QObject *parent = 0);
     ~TransferManager();
@@ -30,7 +38,7 @@ public:
     inline void setNetworkAccessManager(QNetworkAccessManager *manager) { m_nam = manager; }
     Q_INVOKABLE void restoreStoredDownloads();
     Q_INVOKABLE int concurrentTransfers() const;
-    Q_INVOKABLE inline int transferCount() const { return this->transferList()->size(); }
+    Q_INVOKABLE inline int count() const { return this->transferList()->size(); }
     inline QList< QSharedPointer<TransferItem> >* transferList() const { return m_transfers; }
     Q_INVOKABLE void addDownloadTransfer(TrackItem *track, bool notify = true);
     void addDownloadTransfer(QSharedPointer<TrackItem> track, bool notify = true);
@@ -60,9 +68,10 @@ private slots:
 signals:
     void alert(const QString &message);
     void transferRemoved(int row);
+    void countChanged(int count);
 
 private:
-    static TransferManager* m_instance;
+    static TransferManager* self;
     QNetworkAccessManager *m_nam;
     QList< QSharedPointer<TransferItem> > *m_transfers;
 #ifdef MEEGO_EDITION_HARMATTAN
