@@ -5,6 +5,7 @@
 #include <QTabBar>
 #include <QStackedWidget>
 #include <QVBoxLayout>
+#include <QKeyEvent>
 
 ArchiveWindow::ArchiveWindow(QWidget *parent) :
     QWidget(parent),
@@ -28,10 +29,28 @@ ArchiveWindow::ArchiveWindow(QWidget *parent) :
     m_vbox->addWidget(m_stack);
 
     this->connect(m_tabBar, SIGNAL(currentChanged(int)), this, SLOT(onCurrentTabChanged(int)));
+
+    this->showTracks();
 }
 
 ArchiveWindow::~ArchiveWindow() {}
 
+void ArchiveWindow::keyPressEvent(QKeyEvent *event) {
+    switch (event->key()) {
+    case Qt::Key_Left:
+        m_tabBar->setCurrentIndex(m_tabBar->currentIndex() - 1);
+        event->accept();
+        return;
+    case Qt::Key_Right:
+        m_tabBar->setCurrentIndex(m_tabBar->currentIndex() + 1);
+        event->accept();
+        return;
+    default:
+        QWidget::keyPressEvent(event);
+        return;
+    }
+}
+
 void ArchiveWindow::showTracks() {
     m_stack->setCurrentWidget(m_tracksTab);
     m_tracksTab->setFocus(Qt::OtherFocusReason);
