@@ -17,6 +17,9 @@ public:
     explicit ArchiveWindow(QWidget *parent = 0);
     ~ArchiveWindow();
 
+protected:
+    void keyPressEvent(QKeyEvent *event);
+
 private:
     void showTracks();
     void showPlaylists();
