@@ -22,6 +22,9 @@ public:
     explicit ChannelWindow(const QString &userId, QWidget *parent = 0);
     explicit ChannelWindow(QSharedPointer<UserItem> user, QWidget *parent);
     ~ChannelWindow();
+
+protected:
+    void keyPressEvent(QKeyEvent *event);
     
 private:
     void showProfile();
