@@ -14,7 +14,7 @@ void HomescreenDelegate::paint(QPainter *painter, const QStyleOptionViewItem &op
     iconRect.setSize(QSize(64, 64));
     iconRect.moveTopLeft(QPoint(iconRect.left() + 8, iconRect.top() + (option.rect.height() / 2 - iconRect.height() / 2)));
 
-    painter->drawImage(iconRect, QImage(index.data(HomescreenModel::IconSourceRole).toString()).scaled(iconRect.size(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
+    painter->drawImage(iconRect, QImage(index.data(HomescreenModel::IconSourceRole).toString()).scaled(iconRect.size(), Qt::KeepAspectRatio, Qt::SmoothTransformation));
 
     QRect textRect = option.rect;
     textRect.setLeft(textRect.left() + 80);
