@@ -30,6 +30,7 @@
 #include "../base/settings.h"
 #include "../base/playbacklistmodel.h"
 #include "../base/utils.h"
+#include "../mediaplayer/gstreamer/mediaplayer.h"
 #include <QMenuBar>
 #include <QListView>
 #include <QHBoxLayout>
@@ -39,7 +40,7 @@
 #include <QTimer>
 #include <QKeyEvent>
 
-MainWindow* MainWindow::m_instance = 0;
+MainWindow* MainWindow::self = 0;
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
@@ -73,7 +74,7 @@ MainWindow::MainWindow(QWidget *parent) :
     m_toggleVolumeButton(new ToolButton(m_toolBar)),
     m_playbackModeButton(new ToolButton(m_toolBar)),
     m_positionLabel(new QLabel("--:--", m_toolBar)),
-    m_slider(new Phonon::SeekSlider(MediaPlayer::instance()->mediaObject(), m_toolBar)),
+    m_slider(new QSlider(Qt::Horizontal, m_toolBar)),
     m_durationLabel(new QLabel("--:--", m_toolBar)),
     m_mediaButtonBar(new ButtonBar(this)),
     m_previousButton(new MediaPlayerButton(MediaPlayerButton::Previous, m_mediaButtonBar)),
@@ -90,8 +91,8 @@ MainWindow::MainWindow(QWidget *parent) :
     m_navigationBar(new NavigationBar(m_homeWindow)),
     m_view(new QListView(m_homeWindow))
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
     else {
         qWarning() << "MainWindow already exists";
@@ -99,7 +100,6 @@ MainWindow::MainWindow(QWidget *parent) :
 
     this->setWindowTitle("MusiKloud");
     this->setCentralWidget(new QWidget(this));
-    this->setMenuBar(this->menuBar());
     this->addToolBar(m_toolBar);
 
     m_searchAction->setShortcut(Qt::CTRL + Qt::Key_S);
@@ -186,11 +186,11 @@ MainWindow::MainWindow(QWidget *parent) :
     this->connect(m_stopButton, SIGNAL(clicked()), m_stopAction, SLOT(trigger()));
     this->connect(m_nextButton, SIGNAL(clicked()), m_nextAction, SLOT(trigger()));
     this->connect(m_volumeControl, SIGNAL(valueChanged(qreal)), MediaPlayer::instance(), SLOT(setVolume(qreal)));
-    this->connect(m_volumeControl, SIGNAL(mutedChanged(bool)), m_muteAction, SLOT(setChecked(bool)));
+    this->connect(m_volumeControl, SIGNAL(mutedChanged(bool)), m_muteAction, SLOT(trigger()));
     this->connect(m_volumeControl, SIGNAL(pressed()), m_volumeTimer, SLOT(stop()));
     this->connect(m_volumeControl, SIGNAL(released()), m_volumeTimer, SLOT(start()));
     this->connect(m_volumeTimer, SIGNAL(timeout()), this, SLOT(showVolumeControl()));
-    this->connect(MediaPlayer::instance(), SIGNAL(stateChanged(Phonon::State)), this, SLOT(onMediaStateChanged(Phonon::State)));
+    this->connect(MediaPlayer::instance(), SIGNAL(stateChanged(Media::State)), this, SLOT(onMediaStateChanged(Media::State)));
     this->connect(MediaPlayer::instance(), SIGNAL(mutedChanged(bool)), this, SLOT(onVolumeMutedChanged(bool)));
     this->connect(MediaPlayer::instance(), SIGNAL(positionChanged(qint64)), this, SLOT(onPlaybackPositionChanged(qint64)));
     this->connect(MediaPlayer::instance(), SIGNAL(durationChanged(qint64)), this, SLOT(onPlaybackDurationChanged(qint64)));
@@ -202,7 +202,7 @@ MainWindow::MainWindow(QWidget *parent) :
 MainWindow::~MainWindow() {}
 
 MainWindow* MainWindow::instance() {
-    return !m_instance ? new MainWindow : m_instance;
+    return !self ? new MainWindow : self;
 }
 
 bool MainWindow::event(QEvent *event) {
@@ -271,15 +271,15 @@ void MainWindow::keyPressEvent(QKeyEvent *event) {
     QMainWindow::keyPressEvent(event);
 }
 
-void MainWindow::onMediaStateChanged(Phonon::State state) {
+void MainWindow::onMediaStateChanged(Media::State state) {
     switch (state) {
-    case Phonon::PlayingState:
+    case Media::Playing:
         m_playPauseAction->setText(tr("Pause"));
         m_stopAction->setEnabled(true);
         m_playPauseButton->update();
         m_stopButton->update();
         return;
-    case Phonon::PausedState:
+    case Media::Paused:
         m_playPauseAction->setText(tr("Play"));
         m_stopAction->setEnabled(true);
         m_playPauseButton->update();
@@ -327,10 +327,12 @@ void MainWindow::onVolumeMutedChanged(bool muted) {
 
 void MainWindow::onPlaybackPositionChanged(qint64 position) {
     m_durationLabel->setText(Utils::durationFromMSecs(position));
+    m_slider->setValue(position);
 }
 
 void MainWindow::onPlaybackDurationChanged(qint64 duration) {
     m_durationLabel->setText(!duration ? "--:--" : Utils::durationFromMSecs(duration));
+    m_slider->setMaximum(duration);
 }
 
 void MainWindow::setFullScreen(bool fullScreen) {
