@@ -25,7 +25,7 @@ private slots:
     void onPlaybackQueueChanged(int count);
     void onPlaybackPositionChanged(qint64 position);
     void onPlaybackDurationChanged(qint64 duration);
-    void onPlaybackModeChanged(PlaybackMode::Mode playbackMode);
+    void onPlaybackModeChanged(Media::PlaybackMode playbackMode);
     void onSliderReleased();
     void onVolumeButtonClicked(bool checked);
     void onVolumeTimeout();
