@@ -22,6 +22,9 @@ public:
     explicit MyChannelWindow(QWidget *parent = 0);
     ~MyChannelWindow();
 
+protected:
+    void keyPressEvent(QKeyEvent *event);
+
 private:
     void showProfile();
     void showTracks();
