@@ -13,7 +13,7 @@
 #include "../base/settings.h"
 #include "../base/soundcloud.h"
 #include "../base/tracklauncher.h"
-#include "../base/mediaplayer.h"
+#include "../mediaplayer/mobility/mediaplayer.h"
 #include "listview.h"
 #include "thumbnaillabel.h"
 #include "separatorlabel.h"
