@@ -13,7 +13,7 @@
 #include "../base/playbacklistmodel.h"
 #include "../base/settings.h"
 #include "../base/tracklauncher.h"
-#include "../base/mediaplayer.h"
+#include "../mediaplayer/mobility/mediaplayer.h"
 #include <QLabel>
 #include <QMenu>
 #include <QAction>
