@@ -2,6 +2,7 @@
 #define CHANNELWINDOW_H
 
 #include "stackedwindow.h"
+#include "../base/useritem.h"
 
 class ProfileTab;
 class TrackListTab;
@@ -18,8 +19,10 @@ class ChannelWindow : public StackedWindow
 
 public:
     explicit ChannelWindow(const QString &userId, QWidget *parent);
+    explicit ChannelWindow(QSharedPointer<UserItem> user, QWidget *parent);
 
 private:
+    void init();
     void clearMenuActions();
 
 private slots:
