@@ -6,6 +6,7 @@
 #include "../base/playlistitem.h"
 
 class NavButton;
+class NowPlayingButton;
 class QGridLayout;
 class QAction;
 
@@ -50,6 +51,7 @@ private slots:
     void showTransfers();
     void showArchive();
     void onResourceResolved(const QString &id, Queries::QueryType type);
+    void onMediaPlayerChanged(const QString &mediaPlayer);
 
 private:
     bool event(QEvent *event);
@@ -67,6 +69,7 @@ private:
     NavButton *m_archiveButton;
     NavButton *m_accountsButton;
     NavButton *m_settingsButton;
+    NowPlayingButton *m_nowPlayingButton;
     QAction *m_settingsAction;
     QAction *m_aboutAction;
     QGridLayout *m_grid;
