@@ -15,6 +15,7 @@
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
+    app.setOrganizationName("MusiKloud");
     app.setApplicationName("MusiKloud");
     app.setApplicationVersion(Utils::versionNumberString());
 
@@ -27,7 +28,7 @@ int main(int argc, char *argv[])
     qRegisterMetaType< QSharedPointer<ActivityItem> >("QSharedPointer<ActivityItem>");
     qRegisterMetaType< QList< QSharedPointer<TrackItem> > >("QList< QSharedPointer<TrackItem> >");
 
-    new Session;
+    Session session;
 
     if (!Settings::instance()->language().isEmpty()) {
         QTranslator translator;
@@ -43,7 +44,5 @@ int main(int argc, char *argv[])
 
     window.show();
 
-    QObject::connect(&app, SIGNAL(aboutToQuit()), Session::instance(), SLOT(deleteLater()));
-
     return app.exec();
 }
