@@ -10,7 +10,7 @@
 #include <QApplication>
 #include <QDesktopWidget>
 
-NowPlayingButton* NowPlayingButton::m_instance = 0;
+NowPlayingButton* NowPlayingButton::self = 0;
 
 NowPlayingButton::NowPlayingButton(StackedWindow *parent) :
     QWidget(parent),
@@ -19,8 +19,8 @@ NowPlayingButton::NowPlayingButton(StackedWindow *parent) :
     m_ready(false),
     m_moved(false)
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 
     this->setFixedSize(112, 70);
@@ -49,7 +49,7 @@ NowPlayingButton::NowPlayingButton(StackedWindow *parent) :
 NowPlayingButton::~NowPlayingButton() {}
 
 NowPlayingButton* NowPlayingButton::instance() {
-    return !m_instance ? new NowPlayingButton : m_instance;
+    return !self ? new NowPlayingButton : self;
 }
 
 void NowPlayingButton::showEvent(QShowEvent *event) {
