@@ -45,7 +45,7 @@ signals:
     void readyChanged(bool ready);
 
 private:
-    static NowPlayingButton* m_instance;
+    static NowPlayingButton* self;
     QTimer *m_animationTimer;
     int m_currentFrame;
     QVector<QPixmap> m_images;
