@@ -16,7 +16,7 @@
 #include "../base/thumbnailcache.h"
 #include "../base/settings.h"
 #include "../base/playbacklistmodel.h"
-#include "../base/mediaplayer.h"
+#include "../mediaplayer/mobility/mediaplayer.h"
 #include <QGridLayout>
 #include <QLabel>
 #include <QAction>
