@@ -9,7 +9,7 @@
 #include "../base/playbacklistmodel.h"
 #include "windowstack.h"
 #include "../base/tracklauncher.h"
-#include "../base/mediaplayer.h"
+#include "../mediaplayer/mobility/mediaplayer.h"
 #include "listview.h"
 #include <QAction>
 #include <QLabel>
