@@ -9,9 +9,9 @@ class TrackListModel;
 class ListView;
 class ThumbnailLabel;
 class SeparatorLabel;
+class ScrollArea;
 class QAction;
 class QLabel;
-class QScrollArea;
 class QPushButton;
 class QModelIndex;
 
@@ -65,7 +65,7 @@ private:
     QPushButton *m_playButton;
     SeparatorLabel *m_separator1;
     SeparatorLabel *m_separator2;
-    QScrollArea *m_scrollArea;
+    ScrollArea *m_scrollArea;
 };
 
 #endif // PLAYLISTVIDEOSWINDOW_H
