@@ -6,9 +6,9 @@
 
 class SeparatorLabel;
 class AvatarLabel;
+class ScrollArea;
 class QLabel;
 class QPushButton;
-class QScrollArea;
 class QGridLayout;
 
 class ProfileTab : public AbstractTab
@@ -44,7 +44,7 @@ private:
     QLabel *m_descriptionLabel;
     QLabel *m_noProfileLabel;
     QPushButton *m_followingButton;
-    QScrollArea *m_scrollArea;
+    ScrollArea *m_scrollArea;
     QGridLayout *m_grid;
 };
 
