@@ -8,7 +8,9 @@
 #include "concurrenttransfersselector.h"
 #include "screenorientationselector.h"
 #include "languageselector.h"
+#include "networkproxydialog.h"
 #include <QCheckBox>
+#include <QPushButton>
 #include <QLineEdit>
 #include <QScrollArea>
 #include <QDialogButtonBox>
@@ -24,6 +26,7 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     m_transferStatusCheckbox(new QCheckBox(tr("Start transfers automatically"), this)),
     m_eventFeedCheckbox(new QCheckBox(tr("Publish dashboard to event feed"), this)),
     m_clipboardCheckbox(new QCheckBox(tr("Monitor clipboard for URLs"), this)),
+    m_proxyButton(new QPushButton(tr("Network proxy"), this)),
     m_downloadFolderSelector(new QMaemo5ValueButton(tr("Download folder"), this)),
     m_mediaPlayerSelector(new MediaPlayerSelector(tr("Media player"), this)),
     m_downloadFormatSelector(new DownloadFormatSelector(tr("Download format"), this)),
@@ -33,7 +36,8 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     m_mediaPlayerCommandEdit(new QLineEdit(Settings::instance()->mediaPlayerCommand(), this)),
     m_buttonBox(new QDialogButtonBox(QDialogButtonBox::Cancel | QDialogButtonBox::Save, Qt::Vertical, this)),
     m_scrollArea(new QScrollArea(this)),
-    m_grid(new QGridLayout(this))
+    m_grid(new QGridLayout(this)),
+    m_proxyDialog(0)
 {
     this->setWindowTitle(tr("Settings"));
 
@@ -43,7 +47,7 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
 
     QWidget *scrollWidget = new QWidget(m_scrollArea);
     QVBoxLayout *vbox = new QVBoxLayout(scrollWidget);
-
+    vbox->setContentsMargins(0, 0, 0, 0);
     vbox->addWidget(new SeparatorLabel(tr("Media/content"), this));
     vbox->addWidget(m_downloadFolderSelector);
     vbox->addWidget(m_subfoldersCheckbox);
@@ -61,6 +65,7 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     vbox->addWidget(new SeparatorLabel(tr("Other"), this));
     vbox->addWidget(m_orientationSelector);
     vbox->addWidget(m_languageSelector);
+    vbox->addWidget(m_proxyButton);
 
     m_scrollArea->setWidgetResizable(true);
     m_scrollArea->setWidget(scrollWidget);
@@ -70,6 +75,7 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     this->connect(m_buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
     this->connect(m_downloadFolderSelector, SIGNAL(clicked()), this, SLOT(showFileDialog()));
     this->connect(m_mediaPlayerSelector, SIGNAL(valueChanged(QString)), this, SLOT(onMediaPlayerChanged(QString)));
+    this->connect(m_proxyButton, SIGNAL(clicked()), this, SLOT(showNetworkProxyDialog()));
 
     this->loadSettings();
     this->onOrientationChanged();
@@ -154,6 +160,14 @@ void SettingsDialog::showFileDialog() {
     m_downloadFolderSelector->setValueText(m_downloadPath);
 }
 
+void SettingsDialog::showNetworkProxyDialog() {
+    if (!m_proxyDialog) {
+        m_proxyDialog = new NetworkProxyDialog(this);
+    }
+
+    m_proxyDialog->open();
+}
+
 void SettingsDialog::onMediaPlayerChanged(const QString &player) {
     m_mediaPlayerCommandEdit->setEnabled(player == "other");
 }
