@@ -3,6 +3,7 @@
 
 #include "abstractdialog.h"
 
+class NetworkProxyDialog;
 class MediaPlayerSelector;
 class DownloadFormatSelector;
 class ConcurrentTransfersSelector;
@@ -25,6 +26,7 @@ public:
 private slots:
     void saveSettings();
     void showFileDialog();
+    void showNetworkProxyDialog();
     void onMediaPlayerChanged(const QString &player);
 
 private:
@@ -41,6 +43,7 @@ private:
     QCheckBox *m_transferStatusCheckbox;
     QCheckBox *m_eventFeedCheckbox;
     QCheckBox *m_clipboardCheckbox;
+    QPushButton *m_proxyButton;
     QMaemo5ValueButton *m_downloadFolderSelector;
     QString m_downloadPath;
     MediaPlayerSelector *m_mediaPlayerSelector;
@@ -52,6 +55,7 @@ private:
     QDialogButtonBox *m_buttonBox;
     QScrollArea *m_scrollArea;
     QGridLayout *m_grid;
+    NetworkProxyDialog *m_proxyDialog;
     bool m_eventFeedEnabled;
 };
 
