@@ -9,7 +9,7 @@ class SeparatorLabel;
 class ThumbnailLabel;
 class CommentListModel;
 class ListView;
-class QScrollArea;
+class ScrollArea;
 class QAction;
 class QModelIndex;
 
@@ -62,7 +62,7 @@ private:
     SeparatorLabel *m_commentsSeparator;
     CommentListModel *m_commentsModel;
     ListView *m_commentsView;
-    QScrollArea *m_scrollArea;
+    ScrollArea *m_scrollArea;
 };
 
 #endif // TRACKINFOWINDOW_H
