@@ -12,7 +12,7 @@
 #include "../base/transfermanager.h"
 #include "../base/playbacklistmodel.h"
 #include "../base/tracklauncher.h"
-#include "../base/mediaplayer.h"
+#include "../mediaplayer/mobility/mediaplayer.h"
 #include <QAction>
 #include <QLabel>
 #include <QMenuBar>
