@@ -519,13 +519,13 @@ void TransferItem::onPlaylistThumbnailDownloadFinished() {
 
 void TransferItem::moveDownloadedFiles() {
     QString oldFileName = this->downloadPath() + m_track.data()->id();
-    QString newFileName = Settings::instance()->createArtistSubfolders() ? QString("%1%2/%3.%4").arg(Settings::instance()->downloadPath()).arg(m_track.data()->artist()).arg(m_track.data()->title().replace(illegalChars, "_")).arg(m_format == AudioFormats::OriginalFormat ? m_track.data()->format().toLower()
+    QString newFileName = Settings::instance()->createArtistSubfolders() ? QString("%1%2/%3.%4").arg(Settings::instance()->downloadPath()).arg(m_track.data()->artist().replace(illegalChars, "_")).arg(m_track.data()->title().replace(illegalChars, "_")).arg(m_format == AudioFormats::OriginalFormat ? m_track.data()->format().toLower()
                                                                                                                                                                                                                                                                               : QString("mp3"))
                                                                          : QString("%1%2.%3").arg(Settings::instance()->downloadPath()).arg(m_track.data()->title().replace(illegalChars, "_")).arg(m_format == AudioFormats::OriginalFormat ? m_track.data()->format().toLower()
                                                                                                                                                                                                                                              : QString("mp3"));
 
     if (Settings::instance()->createArtistSubfolders()) {
-        QDir(Settings::instance()->downloadPath()).mkdir(m_track.data()->artist());
+        QDir(Settings::instance()->downloadPath()).mkdir(m_track.data()->artist().replace(illegalChars, "_"));
     }
 
     qDebug() << "Old fileName: " + oldFileName;
