@@ -2,10 +2,12 @@
 #include "userlistdelegate.h"
 #include "tracklistwindow.h"
 #include "channelwindow.h"
+#include "windowstack.h"
+#include "listview.h"
+#include "nowplayingbutton.h"
 #include "../base/userlistmodel.h"
 #include "../base/notifications.h"
-#include "../base/windowstack.h"
-#include "listview.h"
+#include "../base/settings.h"
 #include <QLabel>
 #include <QGridLayout>
 #include <QAction>
@@ -22,6 +24,7 @@ UserListTab::UserListTab(QWidget *parent) :
     m_grid->addWidget(m_listView, 0, 0);
     m_listView->setModel(m_model);
     m_listView->setItemDelegate(new UserListDelegate(m_listView));
+    m_listView->setMonitorScrolling(true);
     m_noResultsLabel->hide();
 
     this->connect(m_model, SIGNAL(loadingChanged(bool)), this, SLOT(onLoadingChanged(bool)));
@@ -29,6 +32,11 @@ UserListTab::UserListTab(QWidget *parent) :
     this->connect(m_listView, SIGNAL(clicked(QModelIndex)), this, SLOT(onItemClicked(QModelIndex)));
     this->connect(m_listView, SIGNAL(atEnd()), m_model, SLOT(getMoreUsers()));
 
+    if (Settings::instance()->mediaPlayer() == "musikloud") {
+        this->connect(m_listView, SIGNAL(scrollingStarted()), NowPlayingButton::instance(), SLOT(hide()));
+        this->connect(m_listView, SIGNAL(scrollingStopped()), NowPlayingButton::instance(), SLOT(poke()));
+    }
+
     this->onOrientationChanged();
 }
 
