@@ -1,18 +1,18 @@
 #include "windowstack.h"
 #include "stackedwindow.h"
 
-WindowStack* WindowStack::m_instance = 0;
+WindowStack* WindowStack::self = 0;
 
 WindowStack::WindowStack(QObject *parent) :
     QObject(parent)
 {
-    if (!m_instance) {
-        m_instance = this;
+    if (!self) {
+        self = this;
     }
 }
 
 WindowStack*  WindowStack::instance() {
-    return !m_instance ? new WindowStack : m_instance;
+    return !self ? new WindowStack : self;
 }
 
 StackedWindow* WindowStack::currentWindow() const {
