@@ -25,7 +25,7 @@ signals:
     void currentWindowChanged(StackedWindow *window);
     
 private:
-    static WindowStack* m_instance;
+    static WindowStack* self;
     QList<StackedWindow*> m_windowStack;
 };
 
