@@ -18,14 +18,24 @@
 #include <QSqlDatabase>
 #include <QSqlQuery>
 #include <QSqlRecord>
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
 #include <QNetworkConfigurationManager>
 #include <QNetworkSession>
+#ifdef MEEGO_EDITION_HARMATTAN
 #include <meegotouchevents/meventfeed.h>
+#else
+#include <meegotouchevents-qt5/meventfeed.h>
+#endif
 #endif
 #ifdef Q_WS_MAEMO_5
 #include "alarm.h"
 #endif
+#if QT_VERSION >= 0x050000
+const QString HOME_DIR(QStandardPaths::writableLocation(QStandardPaths::HomeLocation));
+#else
+#include <QDesktopServices>
+const QString HOME_DIR(QDesktopServices::storageLocation(QDesktopServices::HomeLocation));
+#endif
 
 using namespace QtJson;
 
@@ -40,7 +50,7 @@ Events::Events(QObject *parent) :
 
 void Events::init() {
     m_soundcloud->setNetworkAccessManager(m_nam);
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
     QNetworkConfigurationManager configManager;
     QNetworkSession *session = new QNetworkSession(configManager.defaultConfiguration(), this);
     session->setSessionProperty("ConnectInBackground", true);
@@ -49,7 +59,7 @@ void Events::init() {
     session->open();
 #endif
     QSqlDatabase database(QSqlDatabase::addDatabase("QSQLITE"));
-    database.setDatabaseName("/home/user/MusiKloud/MusiKloud.sqlite");
+    database.setDatabaseName(HOME_DIR + "/MusiKloud/MusiKloud.sqlite");
     database.open();
 
     QSqlQuery query;
@@ -70,7 +80,7 @@ void Events::init() {
 
 bool Events::enableSync() {
     QSettings settings("MusiKloud", "MusiKloud");
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
     settings.setValue("Events/eventFeedEnabled", true);
     bool success = true;
 #else
@@ -93,7 +103,7 @@ bool Events::enableSync() {
 
 bool Events::disableSync() {
     QSettings settings("MusiKloud", "MusiKloud");
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
     settings.remove("Events/latestEvent");
     settings.setValue("Events/eventFeedEnabled", false);
     MEventFeed::instance()->removeItemsBySourceName("musikloud");
@@ -146,6 +156,9 @@ void Events::getEvents() {
         QNetworkReply *reply = m_soundcloud->createReply(ALL_ACTIVITIES_FEED);
         this->connect(reply, SIGNAL(finished()), this, SLOT(processEvents()));
     }
+    else {
+        this->syncFailed();
+    }
 }
 
 void Events::processEvents() {
@@ -183,7 +196,7 @@ void Events::processEvents() {
             if (!m_events.isEmpty()) {
                 QSettings("MusiKloud", "MusiKloud").setValue("Events/latestEvent", m_events.first().date());
             }
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
             this->downloadThumbnails();
 #else
             this->addEvents();
@@ -201,7 +214,7 @@ void Events::processEvents() {
 }
 
 void Events::addEvents() {
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
     while (!m_events.isEmpty()) {
         QVariantList args;
         QVariantMap itemArgs;
@@ -216,6 +229,7 @@ void Events::addEvents() {
         itemArgs.insert("sourceName", QString("musikloud"));
         itemArgs.insert("sourceDisplayName", QString("MusiKloud"));
 
+#ifdef MEEGO_EDITION_HARMATTAN
         switch (event.activityType()) {
         case Activities::Playlist:
             itemArgs.insert("action", "com.maemo.MusiKloud / com.maemo.MusiKloud displayPlaylist " + this->base64SerializedVariant(event.id()));
@@ -228,6 +242,12 @@ void Events::addEvents() {
         args.append(itemArgs);
 
         QDBusInterface("com.nokia.home.EventFeed", "/eventfeed", "com.nokia.home.EventFeed").callWithArgumentList(QDBus::Block, "addItem", args);
+#else
+        itemArgs.insert("url", event.url().toString());
+        args.append(itemArgs);
+
+        QDBusInterface("org.nemomobile.events.EventFeed", "/org/nemomobile/events/EventFeed", "org.nemomobile.events.EventFeed").callWithArgumentList(QDBus::Block, "addItem", args);
+#endif
     }
 #else
     while (!m_events.isEmpty()) {
@@ -257,7 +277,7 @@ void Events::addEvents() {
     this->syncSuccess();
 }
 
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
 QString Events::base64SerializedVariant(const QVariant &value) const
 {
     QByteArray ba;
@@ -268,7 +288,7 @@ QString Events::base64SerializedVariant(const QVariant &value) const
 
 void Events::downloadThumbnails() {
     if ((m_index >= 0) && (m_index < m_events.size())) {
-        QFileInfo info(QString("/home/user/MusiKloud/.feedthumbnails/%1.jpg").arg(m_events[m_index].id()));
+        QFileInfo info(QString("%1/MusiKloud/.feedthumbnails/%2.jpg").arg(HOME_DIR).arg(m_events[m_index].id()));
 
         if (info.exists()) {
             m_events[m_index].setThumbnailUrl(QUrl::fromLocalFile(info.absoluteFilePath()));
@@ -294,9 +314,9 @@ void Events::onThumbnailDownloaded() {
         return;
     }
 
-    QDir dir("/home/user/MusiKloud/.feedthumbnails/");
+    QDir dir(HOME_DIR + "/MusiKloud/.feedthumbnails/");
     dir.mkpath(dir.path());
-    QFile file(QString("/home/user/MusiKloud/.feedthumbnails/%1.jpg").arg(m_events[m_index].id()));
+    QFile file(QString("%1/%2.jpg").arg(dir.path()).arg(m_events[m_index].id()));
 
     if (file.open(QIODevice::WriteOnly)) {
         file.write(reply->readAll());
@@ -310,7 +330,7 @@ void Events::onThumbnailDownloaded() {
 }
 
 void Events::clearThumbnails() {
-    QDir dir("/home/user/MusiKloud/.feedthumbnails/");
+    QDir dir(HOME_DIR + "/MusiKloud/.feedthumbnails/");
 
     foreach (QString thumbnail, dir.entryList(QStringList("*.jpg"))) {
         dir.remove(thumbnail);
