@@ -29,14 +29,14 @@ private slots:
     void syncFailed();
     void getEvents();
     void processEvents();
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
     void onThumbnailDownloaded();
 #endif
 
 private:
     void init();
     void addEvents();
-#ifdef MEEGO_EDITION_HARMATTAN
+#if (defined (MEEGO_EDITION_HARMATTAN)) || (defined (Q_WS_SAILFISH))
     QString base64SerializedVariant(const QVariant &value) const;
     void downloadThumbnails();
     void clearThumbnails();
